// Copyright 2024 Florian Beisel
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

import React, { useState, useEffect } from 'react';
import axios from 'axios';
import List from '@mui/material/List';
import ListItem from '@mui/material/ListItem';
import ListItemButton from '@mui/material/ListItemButton';
import ListItemText from '@mui/material/ListItemText';
import { useNavigate } from 'react-router-dom';
import { Dialog, DialogTitle, DialogContent, TextField, DialogActions, Button, Typography } from '@mui/material';


function CategorySelection() {
    const API_BASE_URL = window._env_.REACT_APP_API_BASE_URL;
    const navigate = useNavigate();
    const [categories, setCategories] = useState({});
    const [error, setError] = useState('');

    const handleCategorySelection = (category) => {
        navigate(`/categories/${category}`);
    };

    const handleLogout = () => {
        localStorage.removeItem('token'); // Assuming the token is stored in local storage
        navigate('/login'); // Redirect to login page
    };

    useEffect(() => {
        const fetchCategories = async () => {
            try {
                const token = localStorage.getItem('token'); // Retrieve the stored JWT token
                const response = await axios.get(`${API_BASE_URL}/rules`, {
                    headers: {
                        Authorization: `Bearer ${token}` // Include the JWT token in the request header
                    }
                });
                setCategories(response.data);
            } catch (error) {
                console.error('Error fetching categories:', error);
                setError('Failed to load categories');
            }
        };

        fetchCategories();
    }, []);

    return (
        <div>
            <Typography variant="h2" gutterBottom>
                Select a Category
            </Typography>
            {error && <p style={{ color: 'red' }}>{error}</p>}
            <Button onClick={handleLogout}>Logout</Button>
            <List>
                {Object.entries(categories).map(([key, description]) => (
                    <ListItem key={key} disablePadding>
                        <ListItemButton onClick={() => handleCategorySelection(key)}>
                            <ListItemText primary={key} secondary={description} />
                        </ListItemButton>

                    </ListItem>
                ))}
            </List>
        </div>
    );
}



export default CategorySelection;
