import React, { useState, useEffect } from 'react';
import axios from 'axios';
import { Dialog, DialogTitle, DialogContent, TextField, DialogActions, Button } from '@mui/material';
import PropTypes from 'prop-types';

HostnameDialog.propTypes = {
    // ... other prop types ...
    onSuccessfulSave: PropTypes.func.isRequired,
};

function HostnameDialog({ open, onClose, hostnameDetails, inputStructure, category, fetchHostnameDetails, onSuccessfulSave }) {
    const [formData, setFormData] = useState({});
    const API_BASE_URL = window._env_.REACT_APP_API_BASE_URL;
    const [isFormChanged, setIsFormChanged] = useState(false);


    useEffect(() => {
        if (open) {
            setIsFormChanged(false);
            const initialFormData = hostnameDetails
                ? { ...hostnameDetails, Parameters: hostnameDetails.Parameters || {} }
                : Object.fromEntries(Object.keys(inputStructure).map(key => [key, '']));

            setFormData(initialFormData);
        }
        if (!open) {
            // Reset formData when the dialog is closed
            setFormData({ Parameters: Object.fromEntries(Object.keys(inputStructure).map(key => [key, ''])) });
        }
    }, [open, hostnameDetails, inputStructure]);


    const handleInputChange = (event, key) => {
        const newValue = event.target.value;
        setIsFormChanged(true); // Set the flag to true as form data is being modified

        // Check if the key belongs to 'Parameters'
        if (key in formData.Parameters) {
            setFormData({
                ...formData,
                Parameters: {
                    ...formData.Parameters,
                    [key]: newValue
                }
            });
        } else {
            setFormData({ ...formData, [key]: newValue });
        }
    };

    const handleSave = async () => {
        try {
            const token = localStorage.getItem('token');
            let response;

            if (hostnameDetails && hostnameDetails.Hostname) {
                // Update existing hostname (PUT request)
                response = await axios.put(`${API_BASE_URL}/${hostnameDetails.Category}/${hostnameDetails.Hostname}`, formData.Parameters, {
                    headers: { Authorization: `Bearer ${token}` }
                });
            } else {
                // Add new hostname (POST request)
                response = await axios.post(`${API_BASE_URL}/${category}`, formData, {
                    headers: { Authorization: `Bearer ${token}` }
                });
            }

            if (response.status === 200) {
                onSuccessfulSave(`Hostname saved: ${JSON.stringify(response.data.Hostname, null, 2)}`);
            }
        } catch (error) {
            console.error('Error in operation:', error);
            // Handle errors (e.g., display an error message)
        }

        onClose(); // Close the dialog after attempting to save
    };




    return (
        <div>
            <Dialog open={open} onClose={onClose}>
                <DialogTitle>{hostnameDetails ? 'Edit Hostname' : 'Add Hostname'}</DialogTitle>
                <DialogContent>
                    {formData && formData.Parameters && Object.keys(inputStructure).map((key) => {
                        return (
                            <TextField
                                key={key}
                                label={key}
                                value={key in formData.Parameters ? formData.Parameters[key] : formData[key]}
                                onChange={(e) => handleInputChange(e, key)} // This should update the component's state
                                fullWidth
                                margin="normal"
                            />
                        );
                    })}
                </DialogContent>

                <DialogActions>
                    <Button onClick={onClose}>Cancel</Button>
                    <Button onClick={handleSave} disabled={!isFormChanged}>Save</Button>
                </DialogActions>
            </Dialog>
        </div>

    );
}

export default HostnameDialog;
